@@ -81,7 +81,7 @@ class autoModel(pl.LightningModule):
         # print(x.size())
         
         
-        loss = self.decoder (x, y,reduction="token_mean")
+        loss = self.decoder (x, y.long(),reduction="token_mean")
         loss=loss*-1
         if decode:
             pred=self.decoder.decode(x)
@@ -102,9 +102,10 @@ class autoModel(pl.LightningModule):
         # training_step defined the train loop.
         # It is independent of forward
         x,x_attention_mask,y,y_attention_mask = batch
+        y=y.int()
         pred,loss  = self(x,y,x_attention_mask,y_attention_mask,decode=True)
 #         print("outputs",outputs.size())
-        acc=self.accuracy(torch.Tensor(pred).to(self.device).view(-1), y.reshape(-1))
+        acc=self.accuracy(torch.Tensor(pred).to(self.device).view(-1).int(), y.reshape(-1))
         metrics = {"val_acc": acc, "val_loss": loss}
         # print(pred)
         # metrics = { "val_loss": loss}
@@ -115,9 +116,10 @@ class autoModel(pl.LightningModule):
         # training_step defined the train loop.
         # It is independent of forward
         x,x_attention_mask,y,y_attention_mask = batch
+        y=y.int()
         pred,loss  = self(x,y,x_attention_mask,y_attention_mask,decode=True)
 #         print("outputs",outputs.size())
-        acc=self.accuracy(torch.Tensor(pred).to(self.device).view(-1), y.reshape(-1))
+        acc=self.accuracy(torch.Tensor(pred).to(self.device).view(-1).int(),y.reshape(-1))
         metrics = {"test_acc": acc, "test_loss": loss}
         self.log_dict(metrics)
         return metrics
